package com.qunzhixinxi.hnqz.admin.mapper;


import com.baomidou.mybatisplus.annotation.SqlParser;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.qunzhixinxi.hnqz.admin.entity.WmDaTrack;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 档案-项目管理
 *
 * @author Liujh
 * @date 2020-12-8
 */
@Mapper
public interface WmDaTrackMapper extends BaseMapper<WmDaTrack> {
    int deleteByPrimaryKey(Integer id);

    int insert(WmDaTrack record);

    int insertSelective(WmDaTrack record);

    WmDaTrack selectByPrimaryKey(Integer id);

    int updateByPrimaryKeySelective(WmDaTrack record);

    int updateByPrimaryKey(WmDaTrack record);

	public List<WmDaTrack> listWmDaTrack(WmDaTrack wmDaTrack);

	int deleteByProjectId(Long projectId);
}